import sys
import subprocess
from PyQt5.QtWidgets import QApplication, QWidget, QLabel, QComboBox, QPushButton, QVBoxLayout, QMessageBox, QTextEdit, QFileDialog

class FileSystemConverter(QWidget):
    def __init__(self):
        super().__init__()
        self.initUI()

    def initUI(self):
        self.setWindowTitle('File System Converter')
        
        self.label = QLabel('בחר כונן:', self)
        self.comboBox = QComboBox(self)
        self.comboBox.addItems(['D:','E:', 'F:', 'G:'])  # הוסף כוננים לפי הצורך
        
        self.browseButton = QPushButton('עיון', self)
        self.browseButton.clicked.connect(self.browseDrive)

        self.convertButton = QPushButton('המיר ל-NTFS', self)
        self.convertButton.clicked.connect(self.convertFileSystem)

        self.outputTextEdit = QTextEdit(self)
        self.outputTextEdit.setReadOnly(True)  # תיבת טקסט לקריאה בלבד

        layout = QVBoxLayout()
        layout.addWidget(self.label)
        layout.addWidget(self.comboBox)
        layout.addWidget(self.browseButton)  # הוספת כפתור העיון
        layout.addWidget(self.convertButton)
        layout.addWidget(self.outputTextEdit)  # הוספת תיבת הטקסט
        
        self.setLayout(layout)
        self.resize(400, 300)

    def browseDrive(self):
        # פתיחת סייר הקבצים לבחירת כונן
        drive = QFileDialog.getExistingDirectory(self, "בחר כונן")
        if drive:
            # הוספת הכונן לתיבת הבחירה
            self.comboBox.addItem(drive + '\\')  # הוספת הכונן עם תו הסוף המתאים

    def convertFileSystem(self):
        drive = self.comboBox.currentText()
        command = f'convert {drive} /fs:ntfs'
        
        try:
            # הרצת הפקודה ושמירת הפלט
            result = subprocess.run(command, check=True, shell=True, capture_output=True, text=True)
            self.outputTextEdit.setPlainText(result.stdout)  # הצגת הפלט בתיבת הטקסט
            QMessageBox.information(self, 'הצלחה', f'הכונן {drive} הומר בהצלחה ל-NTFS.')
        except subprocess.CalledProcessError as e:
            self.outputTextEdit.setPlainText(e.stdout + e.stderr)  # הצגת הפלט במקרה של שגיאה
            QMessageBox.critical(self, 'שגיאה', f'אירעה שגיאה: {e}')

if __name__ == '__main__':
    app = QApplication(sys.argv)
    converter = FileSystemConverter()
    converter.show()
    sys.exit(app.exec_())
